@@ -38,14 +38,12 @@ class Q_DECL_HIDDEN KCModuleContainer::KCModuleContainerPrivate
 public:
     KCModuleContainerPrivate(const QStringList &mods)
         : modules(mods)
-        , tabWidget(nullptr)
-        , topLayout(nullptr)
     {}
 
     QStringList modules;
-    QTabWidget *tabWidget;
+    QTabWidget *tabWidget = nullptr;
     KCModule::Buttons buttons;
-    QVBoxLayout *topLayout;
+    QVBoxLayout *topLayout = nullptr;
 
     /**
      * A list containing KCModuleProxy objects which
@@ -80,7 +78,7 @@ KCModuleContainer::KCModuleContainer(QWidget *parent, const QStringList &mods)
 void KCModuleContainer::init()
 {
     d->topLayout = new QVBoxLayout(this);
-    d->topLayout->setMargin(0);
+    d->topLayout->setContentsMargins(0, 0, 0, 0);
     d->topLayout->setObjectName(QStringLiteral("topLayout"));
     d->tabWidget = new QTabWidget(this);
     d->tabWidget->setObjectName(QStringLiteral("tabWidget"));
